@@ -151,7 +151,7 @@ MPEG::~MPEG()
   if(audio) delete audio;
   if(system) delete system;
   
-  SDL_RWclose(source);
+  if(source) SDL_RWclose(source);
   if ( mpeg_mem )
     delete[] mpeg_mem;
 }
@@ -177,10 +177,8 @@ void MPEG::EnableAudio(bool enabled) {
       videoaction->SetTimeSource(NULL);
     }
   }
-/*
   if(audiostream)
     audiostream->enable(enabled);
-*/
 }
 bool MPEG::VideoEnabled(void) {
   return(videoaction_enabled);
@@ -195,12 +193,13 @@ void MPEG::EnableVideo(bool enabled) {
   if ( videoaction && ! videoaction_enabled ) {
     videoaction->Stop();
   } 
+  if(videostream)
+    videostream->enable(enabled);
 }
 
 /* MPEG actions */
 void MPEG::Loop(bool toggle) {
   loop = toggle;
-  system->Loop(toggle);
 }
 void MPEG::Play(void) {
   if ( AudioEnabled() ) {
@@ -409,12 +408,12 @@ bool MPEG::seekIntoStream(int position)
   if(!system->Seek(position)) return(false);
 
   /* Seek first aligned data */
-  if(audiostream)
+  if(audiostream && audioaction_enabled)
     while(audiostream->time() == -1)
-      audiostream->next_packet();
-  if(videostream)
+      if ( ! audiostream->next_packet() ) return false;
+  if(videostream && videoaction_enabled)
     while(videostream->time() == -1)
-      videostream->next_packet();
+      if ( ! videostream->next_packet() ) return false;
 
   /* Calculating current play time on audio only makes sense when there
      is no video */  
